==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Arcuelh deu sit',
'articles' => 'Articles',
'articles_auteur' => 'Articles d\'aqueth autor',
'articles_populaires' => 'Los articles mei populars',
'articles_rubrique' => 'Articles d\'aquera rubrica',
'aucun_article' => 'N\'i a pas nat d\'article a aquera adre&ccedil;a ',
'aucun_auteur' => 'N\'i a pas nat autor a aquera adre&ccedil;a ',
'aucun_site' => 'N\'i a pas nat sit a aquera adre&ccedil;a ',
'aucune_breve' => 'N\'i a pas nada br&egrave;va a aquera adre&ccedil;a ',
'aucune_rubrique' => 'N\'i a pas nada rubrica a aquera adre&ccedil;a ',
'autres_breves' => 'Autas br&egrave;vas',
'autres_groupes_mots_clefs' => 'Autes grops de mots clau',
'autres_sites' => 'Autes sits',

// B
'bonjour' => 'Adishatz',
'breves' => 'Br&egrave;vas',

// C
'commenter_site' => 'Comentar aqueth sit',

// D
'date' => 'Data',
'dernier_ajout' => 'Darr&egrave;r horniment',
'dernieres_breves' => 'Darr&egrave;ras br&egrave;vas',
'derniers_articles' => 'Darr&egrave;rs articles',
'derniers_commentaires' => 'Darr&egrave;rs comentaris',
'derniers_messages_forum' => 'Darr&egrave;rs messatges publicats dens los forums',

// E
'edition_mode_texte' => 'Edicion en m&ograve;de t&egrave;xt de',
'en_reponse' => 'En arresponsa a:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarquia deu sit',

// J
'jours' => 'dias',

// M
'meme_auteur' => 'Deu medish autor',
'meme_rubrique' => 'Dens la medisha rubrica',
'memes_auteurs' => 'Deus medishs autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de forum',
'messages_recents' => 'Los messatges de forums mei recents',
'mots_clefs' => 'Mots clau',
'mots_clefs_meme_groupe' => 'Mots clau dens lo medish grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Las nautats',
'nouveautes_web' => 'Nautats suber lo web',
'nouveaux_articles' => 'Articles naus',
'nouvelles_breves' => 'Br&egrave;vas navas',

// P
'page_precedente' => 'pagina precedenta',
'page_suivante' => 'pagina seguenta',
'par_auteur' => 'per&nbsp;',
'participer_site' => 'Que podetz participar a la vita d\'aqueth sit e perpausar los articles v&ograve;stes en inscrive\'vs &ccedil;a devath. Qu\'arreceberatz suu c&ograve;p un e-mail qui vs\'indicar&agrave; los v&ograve;stes c&ograve;des t&agrave; accedir a l\'espaci privat deu sit.',
'plan_site' => 'Plan deu sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Que podetz prepausar un sit de hornir a aquesta rubrica:',

// R
'repondre_article' => 'Arresp&oacute;ner a aqueth article',
'repondre_breve' => 'Arresp&oacute;ner a aquera br&egrave;va',
'repondre_message' => 'Arresp&oacute;ner a aqueth messatge',
'resultats_recherche' => 'Resultats de la c&egrave;rca',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament deus forums',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realizat dab SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'suite' => 'seguida',
'sur_web' => 'Suber lo web',
'syndiquer_rubrique' => 'Sindicar aquera rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'Ac&iacute; la letra d\'informacion deu sit',
'texte_lettre_information_2' => 'Aquera letra que recensa los articles e br&egrave;vas publicats dempuish',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Vedetz en linha',
'voir_squelette' => 'telecargar l\'esqueleta d\'aquera pagina'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Arcuelh deu sit',
'article' => 'Article', # NEW
'articles' => 'Articles',
'articles_auteur' => 'Articles d\'aqueth autor',
'articles_populaires' => 'Los articles mei populars',
'articles_rubrique' => 'Articles d\'aquera rubrica',
'aucun_article' => 'N\'i a pas nat d\'article a aquera adre&ccedil;a ',
'aucun_auteur' => 'N\'i a pas nat autor a aquera adre&ccedil;a ',
'aucun_site' => 'N\'i a pas nat sit a aquera adre&ccedil;a ',
'aucune_breve' => 'N\'i a pas nada br&egrave;va a aquera adre&ccedil;a ',
'aucune_rubrique' => 'N\'i a pas nada rubrica a aquera adre&ccedil;a ',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Autas br&egrave;vas',
'autres_groupes_mots_clefs' => 'Autes grops de mots clau',
'autres_sites' => 'Autes sits',

// B
'bonjour' => 'Adishatz',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Br&egrave;vas',

// C
'commenter_site' => 'Comentar aqueth sit',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'Data',
'dernier_ajout' => 'Darr&egrave;r horniment',
'dernieres_breves' => 'Darr&egrave;ras br&egrave;vas',
'derniers_articles' => 'Darr&egrave;rs articles',
'derniers_commentaires' => 'Darr&egrave;rs comentaris',
'derniers_messages_forum' => 'Darr&egrave;rs messatges publicats dens los forums',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Edicion en m&ograve;de t&egrave;xt de',
'en_reponse' => 'En arresponsa a:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarquia deu sit',

// J
'jours' => 'dias',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'Deu medish autor',
'meme_rubrique' => 'Dens la medisha rubrica',
'memes_auteurs' => 'Deus medishs autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de forum',
'messages_recents' => 'Los messatges de forums mei recents',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Mots clau',
'mots_clefs_meme_groupe' => 'Mots clau dens lo medish grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Las nautats',
'nouveautes_web' => 'Nautats suber lo web',
'nouveaux_articles' => 'Articles naus',
'nouvelles_breves' => 'Br&egrave;vas navas',

// P
'page_precedente' => 'pagina precedenta',
'page_suivante' => 'pagina seguenta',
'par_auteur' => 'per&nbsp;',
'participer_site' => 'Que podetz participar a la vita d\'aqueth sit e perpausar los articles v&ograve;stes en inscrive\'vs &ccedil;a devath. Qu\'arreceberatz suu c&ograve;p un e-mail qui vs\'indicar&agrave; los v&ograve;stes c&ograve;des t&agrave; accedir a l\'espaci privat deu sit.',
'plan_site' => 'Plan deu sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Que podetz prepausar un sit de hornir a aquesta rubrica:',

// R
'repondre_article' => 'Arresp&oacute;ner a aqueth article',
'repondre_breve' => 'Arresp&oacute;ner a aquera br&egrave;va',
'repondre_message' => 'Arresp&oacute;ner a aqueth messatge',
'resultats_recherche' => 'Resultats de la c&egrave;rca',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament deus forums',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realizat dab SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'spam' => 'Spam', # NEW
'suite' => 'seguida',
'sur_web' => 'Suber lo web',
'syndiquer_rubrique' => 'Sindicar aquera rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'Ac&iacute; la letra d\'informacion deu sit',
'texte_lettre_information_2' => 'Aquera letra que recensa los articles e br&egrave;vas publicats dempuish',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Vedetz en linha',
'voir_squelette' => 'telecargar l\'esqueleta d\'aquera pagina'
);

?>
